[Piglit] [PATCH 21/42] results_tests.py: fix test names

Dylan Baker baker.dylan.c at gmail.com
Wed Apr 22 15:10:10 PDT 2015


Signed-off-by: Dylan Baker <dylanx.c.baker at intel.com>
---
 framework/tests/results_tests.py | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/framework/tests/results_tests.py b/framework/tests/results_tests.py
index e7bc74b..825f992 100644
--- a/framework/tests/results_tests.py
+++ b/framework/tests/results_tests.py
@@ -42,14 +42,13 @@ def test_generate_initialize():
         target()
 
     for target in [results.TestrunResult, results.TestResult]:
-        check.description = "Test that {} initializes".format(
-            target.__name__)
+        check.description = \
+            "results.{}: class initializes".format(target.__name__)
         yield check, target
 
 
 def test_testresult_load_to_status():
     """ TestResult initialized with result key converts the value to a Status
     """
     result = results.TestResult.load({'result': 'pass'})
     assert isinstance(result['result'], status.Status), \
         "Result key not converted to a status object"
@@ -42,14 +42,13 @@ def test_generate_initialize():
 
 def test_testresult_load_to_status():
-    """ TestResult initialized with result key converts the value to a Status
-    """
+    """results.TestResult: an initial status value is converted to a Status object"""
     result = results.TestResult.load({'result': 'pass'})
     assert isinstance(result['result'], status.Status), \
-- 
2.3.5



More information about the Piglit mailing list